/* Copyright (c) 2006, NIF File Format Library and Tools
All rights reserved.  Please see niflib.h for licence. */

#ifndef _BHKRIGIDBODY_H_
#define _BHKRIGIDBODY_H_

#include "bhkEntity.h"

// Include structures
#include "../gen/QuaternionXYZW.h"
#include "../Ref.h"
namespace Niflib {

// Forward define of referenced blocks
class AbhkConstraint;

#include "../gen/obj_defines.h"

class bhkRigidBody;
typedef Ref<bhkRigidBody> bhkRigidBodyRef;

/*!
 * bhkRigidBody - Describes physical properties of an object.
 */

class NIFLIB_API bhkRigidBody : public BHK_RIGID_BODY_PARENT {
public:
	bhkRigidBody();
	~bhkRigidBody();
	//Run-Time Type Information
	static const Type & TypeConst() { return TYPE; }
private:
	static const Type TYPE;
public:
	virtual void Read( istream& in, list<uint> & link_stack, unsigned int version, unsigned int user_version );
	virtual void Write( ostream& out, map<NiObjectRef,uint> link_map, unsigned int version, unsigned int user_version ) const;
	virtual string asString( bool verbose = false ) const;
	virtual void FixLinks( const vector<NiObjectRef> & objects, list<uint> & link_stack, unsigned int version, unsigned int user_version );
	virtual list<NiObjectRef> GetRefs() const;
	virtual const Type & GetType() const;

	void SetTranslation(const Vector3 &v);
	void SetRotation(const QuaternionXYZW &q);
	void SetLayerCopy(int l);	
	void SetCenter(const Vector3 &v);
	void SetMass(float f);
	void SetLinearDamping(float f);
	void SetAngularDamping(float f);
	void SetFriction(float f);
	void SetRestitution(float f);
	void SetMaxLinearVelocity(float f);
	void SetMaxAngularVelocity(float f);
	void SetPenetrationDepth(float f);
	void SetMotionSystem(int i);
	void SetQualityType(int i);

protected:
	BHK_RIGID_BODY_MEMBERS
	STANDARD_INTERNAL_METHODS
};

}
#endif
